@@ -35,12 +35,13 @@ from importlib import import_module
 from io import StringIO, BytesIO
 from mimetypes import MimeTypes
 from pathlib import Path
-from typing import Union, List, Optional, Callable, AsyncGenerator, Type, Tuple
+from typing import Union, List, Optional, Callable, AsyncGenerator, Tuple, Type
 
 import pyrogram
 from pyrogram import __version__, __license__
 from pyrogram import enums
 from pyrogram import raw
+from pyrogram import types
 from pyrogram import utils
 from pyrogram.crypto import aes
 from pyrogram.errors import CDNFileHashMismatch
@@ -61,9 +62,9 @@ from pyrogram.methods import Methods
 from pyrogram.session import Auth, Session
 from pyrogram.storage import FileStorage, MemoryStorage, Storage
 from pyrogram.types import User, TermsOfService
-from pyrogram.utils import ainput
+from pyrogram.utils import ainput, run_sync
 from .connection import Connection
-from .connection.transport import TCP, TCPAbridged
+from .connection.transport import TCPAbridged, TCP
 from .dispatcher import Dispatcher
 from .file_id import FileId, FileType, ThumbnailSource
 from .mime_types import mime_types
@@ -135,13 +136,17 @@ class Client(Methods):
             Only applicable for new sessions.
 
         session_string (``str``, *optional*):
-            Pass a session string to load the session in-memory.
-            Implies ``in_memory=True``.
+            Pass a session string to load the session from a session string.
+            Do you want a .session file? Use ``in_memory=False``,
+            for in-memory use ``in_memory=True``.
 
         is_telethon_string (``bool``, *optional*):
             ``True`` if your provided session_string is in the telethon format.
             Requires ``session_string`` to be filled.
 
+        use_qrcode (``bool``, *optional*):
+            Pass True to login using a QR code.
+
         in_memory (``bool``, *optional*):
             Pass True to start an in-memory session that will be discarded as soon as the client stops.
             In order to reconnect again using an in-memory session without having to login again, you can use
@@ -211,7 +216,7 @@ class Client(Methods):
         max_concurrent_transmissions (``int``, *optional*):
             Set the maximum amount of concurrent transmissions (uploads & downloads).
             A value that is too high may result in network related issues.
-            Defaults to 500.
+            Defaults to 30.
 
         upload_boost (``bool``, *optional*):
             Make pyroblack use more parallel connections for file uploads.
@@ -251,7 +256,7 @@ class Client(Methods):
     # Interval of seconds in which the updates watchdog will kick in
     UPDATES_WATCHDOG_INTERVAL = 10 * 60
 
-    MAX_CONCURRENT_TRANSMISSIONS = 500
+    MAX_CONCURRENT_TRANSMISSIONS = 30
     MAX_MESSAGE_CACHE_SIZE = 10000
 
     mimetypes = MimeTypes()
@@ -275,6 +280,7 @@ class Client(Methods):
         bot_token: str = None,
         session_string: str = None,
         is_telethon_string: bool = False,
+        use_qrcode: Optional[bool] = False,
         in_memory: bool = None,
         storage: Storage = None,
         phone_number: str = None,
@@ -315,6 +321,7 @@ class Client(Methods):
         self.bot_token = bot_token
         self.session_string = session_string
         self.is_telethon_string = is_telethon_string
+        self.use_qrcode = use_qrcode
         self.in_memory = in_memory
         self.phone_number = phone_number
         self.phone_code = phone_code
@@ -340,14 +347,14 @@ class Client(Methods):
 
         if storage:
             self.storage = storage
-        elif self.session_string:
+        elif self.in_memory:
             self.storage = MemoryStorage(
                 self.name, self.session_string, self.is_telethon_string
             )
-        elif self.in_memory:
-            self.storage = MemoryStorage(self.name)
         else:
-            self.storage = FileStorage(self.name, self.workdir)
+            self.storage = FileStorage(
+                self.name, self.workdir, self.session_string, self.is_telethon_string
+            )
 
         self.dispatcher = Dispatcher(self)
 
@@ -420,6 +427,15 @@ class Client(Methods):
             ):
                 await self.invoke(raw.functions.updates.GetState())
 
+    async def _wait_for_update_login_token(self):
+        """
+        Wait for an UpdateLoginToken update from Telegram.
+        """
+        while True:
+            update, _, _ = await self.dispatcher.updates_queue.get()
+            if isinstance(update, raw.types.UpdateLoginToken):
+                break
+
     async def authorize(self) -> User:
         if self.bot_token:
             return await self.sign_in_bot(self.bot_token)
@@ -429,58 +445,65 @@ class Client(Methods):
             f"pyroblack is free software and comes with ABSOLUTELY NO WARRANTY. Licensed\n"
             f"under the terms of the {__license__}.\n"
         )
+        if not self.use_qrcode:
+            while True:
+                try:
+                    if not self.phone_number:
+                        while True:
+                            value = await ainput("Enter phone number or bot token: ")
+
+                            if not value:
+                                continue
+
+                            if value.lower() == "qrcode":
+                                self.use_qrcode = True
+                                break
+
+                            confirm = (
+                                await ainput(f'Is "{value}" correct? (y/N): ')
+                            ).lower()
+
+                            if confirm == "y":
+                                break
+
+                        if ":" in value:
+                            self.bot_token = value
+                            return await self.sign_in_bot(value)
+                        else:
+                            self.phone_number = value
+
+                    sent_code = await self.send_code(self.phone_number)
+                except BadRequest as e:
+                    print(e.MESSAGE)
+                    self.phone_number = None
+                    self.bot_token = None
+                else:
+                    break
+
+            sent_code_descriptions = {
+                enums.SentCodeType.APP: "Telegram app",
+                enums.SentCodeType.SMS: "SMS",
+                enums.SentCodeType.CALL: "phone call",
+                enums.SentCodeType.FLASH_CALL: "phone flash call",
+                enums.SentCodeType.FRAGMENT_SMS: "Fragment SMS",
+                enums.SentCodeType.EMAIL_CODE: "email code",
+            }
+
+            print(
+                f"The confirmation code has been sent via {sent_code_descriptions[sent_code.type]}"
+            )
 
         while True:
-            try:
-                if not self.phone_number:
-                    while True:
-                        value = await ainput("Enter phone number or bot token: ")
-
-                        if not value:
-                            continue
-
-                        confirm = (
-                            await ainput(f'Is "{value}" correct? (y/N): ')
-                        ).lower()
-
-                        if confirm == "y":
-                            break
-
-                    if ":" in value:
-                        self.bot_token = value
-                        return await self.sign_in_bot(value)
-                    else:
-                        self.phone_number = value
-
-                sent_code = await self.send_code(self.phone_number)
-            except BadRequest as e:
-                print(e.MESSAGE)
-                self.phone_number = None
-                self.bot_token = None
-            else:
-                break
-
-        sent_code_descriptions = {
-            enums.SentCodeType.APP: "Telegram app",
-            enums.SentCodeType.SMS: "SMS",
-            enums.SentCodeType.CALL: "phone call",
-            enums.SentCodeType.FLASH_CALL: "phone flash call",
-            enums.SentCodeType.FRAGMENT_SMS: "Fragment SMS",
-            enums.SentCodeType.EMAIL_CODE: "email code",
-        }
-
-        print(
-            f"The confirmation code has been sent via {sent_code_descriptions[sent_code.type]}"
-        )
-
-        while True:
-            if not self.phone_code:
+            if not self.use_qrcode and not self.phone_code:
                 self.phone_code = await ainput("Enter confirmation code: ")
 
             try:
-                signed_in = await self.sign_in(
-                    self.phone_number, sent_code.phone_code_hash, self.phone_code
-                )
+                if self.use_qrcode:
+                    signed_in = await self.sign_in_qrcode()
+                else:
+                    signed_in = await self.sign_in(
+                        self.phone_number, sent_code.phone_code_hash, self.phone_code
+                    )
             except BadRequest as e:
                 print(e.MESSAGE)
                 self.phone_code = None
@@ -528,6 +551,15 @@ class Client(Methods):
                         print(e.MESSAGE)
                         self.password = None
             else:
+                if self.use_qrcode and isinstance(signed_in, types.LoginToken):
+                    time_out = signed_in.expires - datetime.timestamp(datetime.now())
+                    try:
+                        await asyncio.wait_for(
+                            self._wait_for_update_login_token(), timeout=time_out
+                        )
+                    except asyncio.TimeoutError:
+                        print("QR code expired, Requesting new QR code...")
+                    continue
                 break
 
         if isinstance(signed_in, User):
@@ -913,7 +945,8 @@ class Client(Methods):
                         except Exception as e:
                             print(e)
 
-    def is_excluded(self, exclude, module):
+    @staticmethod
+    def is_excluded(exclude, module):
         for e in exclude:
             if module == e or module.startswith(e + "."):
                 return True
@@ -1024,7 +1057,7 @@ class Client(Methods):
                                                     )
 
                                                     count += 1
-                                        except Exception as e:
+                                        except Exception:
                                             pass
             else:
                 for path, handlers in include:
@@ -1126,7 +1159,7 @@ class Client(Methods):
                                                             )
 
                                                             count += 1
-                                                except Exception as e:
+                                                except Exception:
                                                     pass
 
                     if handlers is None:
@@ -1211,11 +1244,11 @@ class Client(Methods):
             async for chunk in self.get_file(
                 file_id, file_size, 0, 0, progress, progress_args
             ):
-                file.write(chunk)
+                await run_sync(file.write, chunk)
         except BaseException as e:
             if not in_memory:
                 file.close()
-                os.remove(temp_file_path)
+                await run_sync(os.remove, temp_file_path)
 
             if isinstance(e, asyncio.CancelledError):
                 raise e
@@ -1231,7 +1264,7 @@ class Client(Methods):
             else:
                 file.close()
                 file_path = os.path.splitext(temp_file_path)[0]
-                shutil.move(temp_file_path, file_path)
+                await run_sync(shutil.move, temp_file_path, file_path)
                 return file_path
 
     async def get_file(
