@@ -248,7 +248,7 @@ react = create(reaction_filter)
 
 # region forwarded_filter
 async def forwarded_filter(_, __, m: Message):
-    return bool(m.forward_date)
+    return bool(m.forward_origin)
 
 
 forwarded = create(forwarded_filter)
@@ -853,7 +853,11 @@ from_scheduled = create(from_scheduled_filter)
 
 # region linked_channel_filter
 async def linked_channel_filter(_, __, m: Message):
-    return bool(m.forward_from_chat and not m.from_user)
+    x = getattr(m.forward_origin, "chat", None)
+    if x:
+        return bool(getattr(x, "sender_chat") and not m.from_user)
+    else:
+        return False
 
 
 linked_channel = create(linked_channel_filter)
@@ -963,7 +967,12 @@ def command(
     command_re = re.compile(r"([\"'])(.*?)(?<!\\)\1|(\S+)")
 
     async def func(flt, client: pyrogram.Client, message: Message):
+        usernames = []
         username = client.me.username or ""
+        if client.me.usernames:
+            usernames.append(username)
+            for user in client.me.usernames:
+                usernames.append(user.username)
         text = message.text or message.caption
         message.command = None
 
@@ -977,6 +986,32 @@ def command(
             without_prefix = text[len(prefix) :]
 
             for cmd in flt.commands:
+                if usernames:
+                    for username in usernames:
+                        if not re.match(
+                            rf"^(?:{cmd}(?:@?{username})?)(?:\s|$)",
+                            without_prefix,
+                            flags=re.IGNORECASE if not flt.case_sensitive else 0,
+                        ):
+                            continue
+
+                        without_command = re.sub(
+                            rf"{cmd}(?:@?{username})?\s?",
+                            "",
+                            without_prefix,
+                            count=1,
+                            flags=re.IGNORECASE if not flt.case_sensitive else 0,
+                        )
+
+                        # match.groups are 1-indexed, group(1) is the quote, group(2) is the text
+                        # between the quotes, group(3) is unquoted, whitespace-split text
+
+                        # Remove the escape character from the arguments
+                        message.command = [cmd] + [
+                            re.sub(r"\\([\"'])", r"\1", m.group(2) or m.group(3) or "")
+                            for m in command_re.finditer(without_command)
+                        ]
+                        return True
                 if not re.match(
                     rf"^(?:{cmd}(?:@?{username})?)(?:\s|$)",
                     without_prefix,
@@ -1096,13 +1131,23 @@ class user(Filter, set):
         )
 
     async def __call__(self, _, message: Message):
-        return message.from_user and (
-            message.from_user.id in self
-            or (
-                message.from_user.username
-                and message.from_user.username.lower() in self
+        is_usernames_in_filters = False
+        if message.from_user and message.from_user.usernames:
+            for username in message.from_user.usernames:
+                if username.username in self or username.username.lower() in self:
+                    is_usernames_in_filters = True
+                    break
+        return (
+            message.from_user
+            and (
+                message.from_user.id in self
+                or (
+                    message.from_user.username
+                    and message.from_user.username.lower() in self
+                )
+                or ("me" in self and message.from_user.is_self)
             )
-            or ("me" in self and message.from_user.is_self)
+            or is_usernames_in_filters
         )
 
 
@@ -1134,35 +1179,55 @@ class chat(Filter, set):
 
     async def __call__(self, _, message: Union[Message, Story]):
         if isinstance(message, Story):
+            is_usernames_in_filters = False
+            if message.sender_chat and message.sender_chat.usernames:
+                for username in message.sender_chat.usernames:
+                    if username.username in self or username.username.lower() in self:
+                        is_usernames_in_filters = True
+                        break
             return (
-                message.sender_chat
-                and (
-                    message.sender_chat.id in self
-                    or (
-                        message.sender_chat.username
-                        and message.sender_chat.username.lower() in self
+                (
+                    message.sender_chat
+                    and (
+                        message.sender_chat.id in self
+                        or (
+                            message.sender_chat.username
+                            and message.sender_chat.username.lower() in self
+                        )
                     )
                 )
-            ) or (
-                message.from_user
-                and (
-                    message.from_user.id in self
-                    or (
-                        message.from_user.username
-                        and message.from_user.username.lower() in self
+                or (
+                    message.from_user
+                    and (
+                        message.from_user.id in self
+                        or (
+                            message.from_user.username
+                            and message.from_user.username.lower() in self
+                        )
                     )
                 )
+                or is_usernames_in_filters
             )
         else:
-            return message.chat and (
-                message.chat.id in self
-                or (message.chat.username and message.chat.username.lower() in self)
-                or (
-                    "me" in self
-                    and message.from_user
-                    and message.from_user.is_self
-                    and not message.outgoing
+            is_usernames_in_filters = False
+            if message.chat and message.chat.usernames:
+                for username in message.chat.usernames:
+                    if username.username in self or username.username.lower() in self:
+                        is_usernames_in_filters = True
+                        break
+            return (
+                message.chat
+                and (
+                    message.chat.id in self
+                    or (message.chat.username and message.chat.username.lower() in self)
+                    or (
+                        "me" in self
+                        and message.from_user
+                        and message.from_user.is_self
+                        and not message.outgoing
+                    )
                 )
+                or (is_usernames_in_filters and not message.outgoing)
             )
 
 
