@@ -18,6 +18,7 @@
 
 from .add_handler import AddHandler
 from .export_session_string import ExportSessionString
+from .ping import Ping
 from .remove_handler import RemoveHandler
 from .restart import Restart
 from .run import Run
@@ -30,6 +31,7 @@ from .stop_transmission import StopTransmission
 class Utilities(
     AddHandler,
     ExportSessionString,
+    Ping,
     RemoveHandler,
     Restart,
     Run,
