@@ -59,14 +59,14 @@ class Result:
 class Session:
     START_TIMEOUT = 10
     WAIT_TIMEOUT = 15
-    RECONN_TIMEOUT = 8
+    RECONN_TIMEOUT = 5
     SLEEP_THRESHOLD = 10
     MAX_RETRIES = 50
     ACKS_THRESHOLD = 10
     PING_INTERVAL = 5
     STORED_MSG_IDS_MAX_SIZE = 1000 * 2
     RECONNECT_THRESHOLD = 5
-    RE_START_RANGE = range(4)
+    RE_START_RANGE = (1, 2, 3, 4, 5, 6)
 
     TRANSPORT_ERRORS = {
         404: "auth key not found",
@@ -119,13 +119,14 @@ class Session:
         self.stop_lock = asyncio.Lock()
         self.restart_lock = asyncio.Lock()
         self.last_reconnect_attempt = None
+        self.skip_updates_ori = client.skip_updates  # save default
 
     async def start(self):
         if self.instant_stop:
             return  # stop instantly
 
         if self.start_lock.locked():
-            log.warning(
+            log.info(
                 f"[pyroblack] Client [{self.client.name}] called start while already starting"
             )
             return  # don't start 2 times at once
@@ -200,20 +201,19 @@ class Session:
             self.is_started.set()
             log.info("Session started")
 
-    async def stop(self, restart: bool = False):
+    async def stop(self):
         if self.instant_stop:
             return  # stop doing anything instantly, force stop
 
         if self.stop_lock.locked():
-            log.warning(
+            log.info(
                 f"[pyroblack] Client [{self.client.name}] called stop while already stopping"
             )
             return  # don't stop 2 times at once
 
         async with self.stop_lock:
             try:
-                if restart:
-                    self.instant_stop = True  # tell all funcs that we want to stop
+                self.instant_stop = True  # tell all funcs that we want to stop
 
                 self.is_started.clear()
                 self.stored_msg_ids.clear()
@@ -255,8 +255,7 @@ class Session:
 
                 log.info("Session stopped")
             finally:
-                if restart:
-                    self.instant_stop = False  # reset
+                self.instant_stop = False  # reset
 
     async def restart(self, stop: bool):
         if self.instant_stop:
@@ -274,6 +273,12 @@ class Session:
             )
             return  # don't restart 2 times at once
 
+        if not self.is_started.is_set():
+            log.info(
+                f"[pyroblack] Client [{self.client.name}] called restart while not being already started"
+            )
+            return  # don't restart when supposed to be stopped
+
         async with self.restart_lock:
             now = time()
             if (
@@ -291,13 +296,15 @@ class Session:
             self.last_reconnect_attempt = time()
             if stop:
                 try:
-                    await self.stop(restart=True)
+                    await self.stop()
                 except Exception as e:
                     log.warning(
                         f"[pyroblack] Client [{self.client.name}] failed stopping; restarting anyways, exc: %s %s",
                         type(e).__name__,
                         e,
                     )
+                self.skip_updates_ori = self.client.skip_updates
+                self.client.skip_updates = False  # get "missed" updates after restart
 
             for try_ in self.RE_START_RANGE:
                 try_ += 1
@@ -320,6 +327,11 @@ class Session:
                             type(e).__name__,
                             e,
                         )
+            if stop:
+                self.client.skip_updates = (
+                    self.skip_updates_ori
+                )  # revert to original setting
+                self.skip_updates_ori = None
 
     async def handle_packet(self, packet):
         if self.instant_stop:
