@@ -28,3 +28,13 @@ from .object import Object
 from .update import *
 from .user_and_chats import *
 from .pyromod import *
+
+__all__ = ["List", "Object", "Update"]
+__all__.extend(authorization.__all__)
+__all__.extend(bots_and_keyboards.__all__)
+__all__.extend(inline_mode.__all__)
+__all__.extend(input_media.__all__)
+__all__.extend(input_message_content.__all__)
+__all__.extend(messages_and_media.__all__)
+__all__.extend(user_and_chats.__all__)
+__all__.extend(pyromod.__all__)
