@@ -16,9 +16,7 @@
 #  You should have received a copy of the GNU Lesser General Public License
 #  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
-import pyrogram
 from pyrogram import raw
-from pyrogram import types
 from ..object import Object
 
 
