@@ -19,7 +19,7 @@
 #  along with pyroblack.  If not, see <http://www.gnu.org/licenses/>.
 
 from datetime import datetime
-from typing import Union, List, Optional, AsyncGenerator, BinaryIO
+from typing import Union, List, Optional, AsyncGenerator, BinaryIO, Dict
 
 import pyrogram
 from pyrogram import raw, enums
@@ -58,9 +58,6 @@ class Chat(Object):
         is_support (``bool``):
             True, if this chat is part of the Telegram support team. Users and bots only.
 
-        is_forum (``bool``, *optional*):
-            True, if the supergroup chat is a forum
-
         is_participants_hidden (``bool``, *optional*):
             True, if the chat members are hidden.
             Returned only in :meth:`~pyrogram.Client.get_chat`.
@@ -81,6 +78,9 @@ class Chat(Object):
         is_paid_reactions_available (``bool``, *optional*):
             True, if paid reactions enabled in this chat.
 
+        is_auto_translation_enabled (``bool``, *optional*):
+            True, if automatic translation is enabled in chat.
+
         title (``str``, *optional*):
             Title, for supergroups, channels and basic group chats.
 
@@ -161,6 +161,10 @@ class Chat(Object):
             The linked discussion group (in case of channels) or the linked channel (in case of supergroups).
             Returned only in :meth:`~pyrogram.Client.get_chat`.
 
+        linked_forum (:obj:`~pyrogram.types.Chat`, *optional*):
+            The linked monoforum (in case of channels) or the linked channel (in case of monoforum).
+            Returned only in :meth:`~pyrogram.Client.get_chat`.
+
         send_as_chat (:obj:`~pyrogram.types.Chat`, *optional*):
             The default "send_as" chat.
             Returned only in :meth:`~pyrogram.Client.get_chat`.
@@ -213,13 +217,13 @@ class Chat(Object):
         is_scam: bool = None,
         is_fake: bool = None,
         is_support: bool = None,
-        is_forum: bool = None,
         is_participants_hidden: bool = None,
         is_join_request: bool = None,
         is_join_to_send: bool = None,
         is_antispam: bool = None,
         is_slowmode_enabled: bool = None,
         is_paid_reactions_available: bool = None,
+        is_auto_translation_enabled: bool = None,
         title: str = None,
         username: str = None,
         first_name: str = None,
@@ -242,6 +246,7 @@ class Chat(Object):
         permissions: "types.ChatPermissions" = None,
         distance: int = None,
         linked_chat: "types.Chat" = None,
+        linked_forum: "types.Chat" = None,
         send_as_chat: "types.Chat" = None,
         available_reactions: Optional["types.ChatReactions"] = None,
         usernames: List["types.Username"] = None,
@@ -262,13 +267,13 @@ class Chat(Object):
         self.is_scam = is_scam
         self.is_fake = is_fake
         self.is_support = is_support
-        self.is_forum = is_forum
         self.is_participants_hidden = is_participants_hidden
         self.is_join_request = is_join_request
         self.is_join_to_send = is_join_to_send
         self.is_antispam = is_antispam
         self.is_slowmode_enabled = is_slowmode_enabled
         self.is_paid_reactions_available = is_paid_reactions_available
+        self.is_auto_translation_enabled = is_auto_translation_enabled
         self.title = title
         self.username = username
         self.first_name = first_name
@@ -291,6 +296,7 @@ class Chat(Object):
         self.permissions = permissions
         self.distance = distance
         self.linked_chat = linked_chat
+        self.linked_forum = linked_forum
         self.send_as_chat = send_as_chat
         self.available_reactions = available_reactions
         self.usernames = usernames
@@ -373,6 +379,16 @@ class Chat(Object):
         restriction_reason = getattr(channel, "restriction_reason", [])
         user_name = getattr(channel, "username", None)
         active_usernames = getattr(channel, "usernames", [])
+        if getattr(channel, "monoforum", None):
+            chat_type = enums.ChatType.MONOFORUM
+        elif getattr(channel, "forum", None):
+            chat_type = enums.ChatType.FORUM
+        elif getattr(channel, "megagroup", None):
+            chat_type = enums.ChatType.SUPERGROUP
+        elif getattr(channel, "broadcast", None):
+            chat_type = enums.ChatType.CHANNEL
+        else:
+            chat_type = enums.ChatType.GROUP
         usernames = None
         if len(active_usernames) >= 1:
             usernames = []
@@ -387,17 +403,12 @@ class Chat(Object):
 
         return Chat(
             id=peer_id,
-            type=(
-                enums.ChatType.SUPERGROUP
-                if getattr(channel, "megagroup", None)
-                else enums.ChatType.CHANNEL
-            ),
+            type=chat_type,
             is_verified=getattr(channel, "verified", None),
             is_restricted=getattr(channel, "restricted", None),
             is_creator=getattr(channel, "creator", None),
             is_scam=getattr(channel, "scam", None),
             is_fake=getattr(channel, "fake", None),
-            is_forum=getattr(channel, "forum", None),
             is_join_request=getattr(channel, "join_request", None),
             is_join_to_send=getattr(channel, "join_to_send", None),
             is_slowmode_enabled=getattr(channel, "slowmode_enabled", None),
@@ -431,8 +442,8 @@ class Chat(Object):
     def _parse(
         client,
         message: Union[raw.types.Message, raw.types.MessageService],
-        users: dict,
-        chats: dict,
+        users: Dict[int, "raw.types.User"],
+        chats: Dict[int, "raw.types.Chat"],
         is_chat: bool,
     ) -> "Chat":
         from_id = utils.get_raw_peer_id(message.from_id)
@@ -448,7 +459,12 @@ class Chat(Object):
         return Chat._parse_channel_chat(client, chats[chat_id])
 
     @staticmethod
-    def _parse_dialog(client, peer, users: dict, chats: dict):
+    def _parse_dialog(
+        client,
+        peer: Union[raw.types.PeerUser, raw.types.PeerChat, raw.types.PeerChannel],
+        users: Dict[int, "raw.types.User"],
+        chats: Dict[int, "raw.types.Chat"],
+    ) -> "Chat":
         if isinstance(peer, raw.types.PeerUser):
             return Chat._parse_user_chat(client, users[peer.user_id])
         elif isinstance(peer, raw.types.PeerChat):
@@ -546,6 +562,9 @@ class Chat(Object):
                 )
                 parsed_chat.is_participants_hidden = full_chat.participants_hidden
                 parsed_chat.is_antispam = full_chat.antispam
+                parsed_chat.is_auto_translation_enabled = getattr(
+                    full_chat, "auto_translation", None
+                )
                 parsed_chat.folder_id = getattr(full_chat, "folder_id", None)
                 parsed_chat.is_paid_reactions_available = getattr(
                     full_chat, "paid_reactions_available", None
@@ -553,11 +572,20 @@ class Chat(Object):
 
                 linked_chat_raw = chats.get(full_chat.linked_chat_id, None)
 
+                linked_forum_raw = chats.get(
+                    getattr(chat_raw, "linked_monoforum_id"), None
+                )
+
                 if linked_chat_raw:
                     parsed_chat.linked_chat = Chat._parse_channel_chat(
                         client, linked_chat_raw
                     )
 
+                if linked_forum_raw:
+                    parsed_chat.linked_forum = Chat._parse_channel_chat(
+                        client, linked_forum_raw
+                    )
+
                 default_send_as = full_chat.default_send_as
 
                 if default_send_as:
